@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 """Classes representing different kinds of astronomical position."""
 
-from numpy import array, einsum, full, reshape, nan, nan_to_num
+from numpy import array, cos, einsum, full, reshape, nan, nan_to_num
 from . import framelib
 from .constants import ANGVEL, AU_M, C, ERAD, DAY_S, RAD2DEG, pi, tau
 from .descriptorlib import reify
@@ -223,7 +223,12 @@ class ICRF(object):
     @reify
     def light_time(self):
         """Length of this vector in days of light travel time."""
-        return self.distance().m / C * DAY_S
+        # Note that this property is almost never called, since
+        # .light_time is set manually on the one kind of position
+        # (astrometric) that is ever likely to need it.  Alas: back in
+        # 2015, I didn't think to either hide this attribute, or have it
+        # include its units in its name!
+        return self.distance().m / C / DAY_S
 
     def radec(self, epoch=None):
         r"""Compute equatorial RA, declination, and distance.
@@ -474,11 +479,57 @@ class ICRF(object):
                 Velocity(d_rate))
 
     def to_skycoord(self, unit=None):
-        """Convert this distance to an AstroPy ``SkyCoord`` object."""
+        """Convert this distance to an AstroPy ``SkyCoord`` object.
+
+        Currently, this will only work with Skyfield positions whose
+        center is the Solar System barycenter or else the geocenter.
+
+        """
         from astropy.coordinates import SkyCoord
         from astropy.units import au
+        if self.center == 0:
+            frame = 'icrs'
+        elif self.center == 399:
+            from astropy.coordinates import GCRS
+            frame = GCRS(obstime=self.t.to_astropy())
+        else:
+            raise NotImplementedError(
+                'Skyfield can only return AstroPy positions for barycentric'
+                ' and geocentric coordinates; if you are interested in adding'
+                ' support for positions whose center={}, please open an issue'
+                .format(self.center)
+            )
+
         x, y, z = self.position.au
-        return SkyCoord(representation_type='cartesian', x=x, y=y, z=z, unit=au)
+        return SkyCoord(frame=frame, representation_type='cartesian',
+                        unit=au, x=x, y=y, z=z)
+
+    def phase_angle(self, sun):
+        """Return this position’s phase angle: the angle Sun-target-observer.
+
+        Given a Sun object (which you can build by loading an ephemeris
+        and looking up ``eph['Sun']``), return the `Angle` between the
+        light arriving at this position’s target from the Sun and the
+        light traveling from this position’s target to the observer.
+
+        .. versionadded:: 1.42
+
+        """
+        return self.separation_from(self.center_barycentric - sun.at(self.t))
+
+    def fraction_illuminated(self, sun):
+        """Return the fraction of the target’s disc that is illuminated.
+
+        Given a Sun object (which you can build by loading an ephemeris
+        and looking up ``eph['Sun']``), compute what fraction from 0.0
+        to 1.0 of this target’s disc is illuminated, under the
+        assumption that the target is a sphere.
+
+        .. versionadded:: 1.42
+
+        """
+        a = self.phase_angle(sun).radians
+        return 0.5 * (1.0 + cos(a))
 
     def is_sunlit(self, ephemeris):
         """Return whether a position in Earth orbit is in sunlight.
